function savm_dcdc_plot(Name,Wf,fn)
% savm_dcdc_plot plots waveforms associated with a dc/dc converter
%
% savm_dcdc_plot(Name,Wf)
% savm_dcdc_plot(Name,Wf,fn)
%
% Inputs:
% Name          = text Description of component
% Wf            = structure of waveform data
%  Wf.Time      = time vector (s)
%  WF.Data(:,1) = output voltage (V)
%  Wf.Data(:,2) = inductor current (A)
% fn            = figure number
%  
% Internal:
% t             = time vector (s)
% il            = inductor current (A)
% vout          = output voltage (V)
%
% Written by:
% S.D. Sudhoff
% Purdue University
% School of Electrical and Computer Engineering
% 1285 Electrical Engineering Building
% West Lafayette, IN 47907-1285
% Phone: 765-494-3246
% Fax: 765-494-0676
% E-mail: sudhoff@ecn.purdue.edu

% Get data
t=Wf.Time;
vout=Wf.Data(:,1);
il   =Wf.Data(:,2);

% plot dc output current
if nargin>2
   figure(fn)
else
   figure
end
plot(t,vout);
xlabel('t, s');
ylabel('v_{out}, V');
grid on;
title([Name, ' DC Output Voltage']);

% plot torque
if nargin>2
   figure(fn+1)
else
   figure
end
plot(t,il);
xlabel('t, s');
ylabel('i_l, A');
grid on;
title([Name, ' Inductor Current']);